*** This do-file creates the figures 1, ... in the main paper
*** Created March 2020

*** Our main file masterv15_a.m at various points exports data in csv files. 
*** These are used here to create the figures in the paper
clear
set more off
pause on


tempfile temp_data1 temp_data2 temp1
* choose directory where the csv files are located
global path1 = "C:\Users\Fabian\Dropbox\Unemployment Projects\Estimating Matching with Theo\Estimation-Matching Function"
* choose directory to export the resulting graphs
global path2 = "C:\Users\Fabian\Dropbox\Unemployment Projects\Estimating Matching with Theo\Draft-Matching Function"

*** Read in data for Figure 1, 2, and 3. These data are deseasonalized.
{
cd "$path1"
filefilter figmain_1.csv figmain_1read.csv, from("NaN") to(".") replace  // This replaces the missing value string in the original file with "." allowing for 
																		 // read-in as numeric variables
import delimited figmain_1read

tokenize v vJolts dfhindex month year s_u EEfemale EEfemaleY EEmale EEmaleY NEfemale NEfemaleY NEmale ///
    NEmaleY UEfemale UEfemaleY UEmale UEmaleY Efemale EfemaleY Emale EmaleY Nfemale NfemaleY Nmale ///
    NmaleY Ufemale UfemaleY Umale UmaleY S
	
forvalues i=1(1)31 {
	rename v`i' ``i''
}
rename s_u MPS
	
// Set the date variable to allow using the time-series commands
gen date = ym(year, month)
format date %tm
tsset date
	
*** Create the count of unemployed equivalents. 
// The Murokayama, Petterson, Sahin equivalent index is based on the unemployed 25-70 together. 
// Thus, we will make that the base group in which to measure the overall searchers (that is as "unemployed 25-70 equivalents")
// THE MPS index gives the average search effort relative to all unemployed 25-70 together - thus we make the reference group the same
gen Uall = Umale + Ufemale
gen UE = UEmale*Umale/Uall + UEfemale*Ufemale/Uall

// total Labor Supply = (Male Unemployed Equivalent) * MPS = (Male Unemployed 25-70) * (Uequiv/Male_Unemployed) * MPS
tokenize EEfemale EEfemaleY EEmale EEmaleY NEfemale NEfemaleY NEmale NEmaleY UEfemaleY UEmaleY UE
 
forvalues i=1(1)11 {
	gen rel`i' = ``i'' / UE
	label var rel`i' "``i'' equivalence units to unemployed 25-70"
}

tokenize Efemale EfemaleY Emale EmaleY Nfemale NfemaleY Nmale NmaleY UfemaleY UmaleY Uall
forvalues i = 1(1)11 {
	gen UMequiv_``i'' = rel`i'*``i''
	label var UMequiv_``i'' "``i'' in Unempl 25-70 equivalents"
}

gen Utotal_equiv =UMequiv_`1'+UMequiv_`2'+UMequiv_`3'+UMequiv_`4'+UMequiv_`5'+UMequiv_`6'+UMequiv_`7'+UMequiv_`8'+UMequiv_`9'+UMequiv_`10'+UMequiv_`11'
gen perU = Utotal_equiv/Uall

// perU =  how many U-equivalents per unemployed individual
label var perU "Composition effect"
}

	
*** Figure 1: Components of Labour Demand
{

gen R = dfhindex*vJolts

label var R "Labor Demand"
label var vJolts "Vacancies (JOLTS, in thousands)"
label var dfhindex "Davis et al. Index"


twoway (tsline R vJolts) (tsline dfhindex, yaxis(2) lpattern(longdash) color(black)) if year>=2001, ///
title("Total Recruitment and Components") ytitle("in thousands") tlabel(2001m1(48)2018m1) graphr(color(white)) saving(figure1_sect6_vacancies, replace)
graph export "$path2\Figure1_section6.png", replace

}

*** Figure 2: Labour Supply and Its Components
{
label var MPS "MPS Index - min per unemployed 25-70"
label var Umale "Unemployed, male 25-70"
label var Ufemale "Unemployed, female 25-70"
label var S "Labor Supply"

preserve
* Index the variables to graph against September 2007
gen month_in_yr = month(dofm(month))

sum S if month_in_yr == 9 & year == 2007
replace S = S / r(mean)

sum MPS if month_in_yr == 9 & year == 2007
replace MPS = MPS / r(mean)

sum Uall if month_in_yr == 9 & year == 2007
replace Uall = Uall / r(mean)

sum perU if month_in_yr == 9 & year == 2007
replace perU = perU / r(mean)


tsline S, name(u1, replace) title("Total Labor Supply") graphr(color(white)) tlabel(2001m1(48)2018m1) xtitle("") ytitle("") nodraw
tsline MPS, name(u2, replace) title("MPS Search Index") graphr(color(white)) tlabel(2001m1(48)2018m1) xtitle("") ytitle("") nodraw
tsline Uall, name(u3,replace) title("# of Unemployed 25-70") graphr(color(white)) tlabel(2001m1(48)2018m1) xtitle("") ytitle("") nodraw
tsline perU, name(u4, replace) title("U-Equivalent per Unemployed") graphr(color(white)) tlabel(2001m1(48)2018m1) xtitle("") ytitle("") nodraw
graph combine u1 u2 u3 u4, title("Labor Supply") graphr(color(white)) plotr(color(white)) ///
note("All series are deseasonalized and indexed to September 2007")

graph export "$path2\Figure2_section6.png", replace

restore
}

*** Figure 3: Beveridge Curve
{
preserve
keep year R S MPS

// The MPS index is measured in minutes spend searching. Thus, the units of S are minute equivalents of unemployed search.
// Express S instead as unemployed-equivalents at their average search. 

qui sum MPS 
replace S = S / r(mean)
sort year 
collapse R S, by(year) 
replace S = S/1000

twoway scatter R S, mlabel(year) msymbol("") connect(l) graphr(color(white)) ///
title("Augmented Beveridge Curve") ///
xtitle("Aggregate Search")  ///
ytitle("Aggregate Recruiting") ///
note("Aggregate Search and Recruiting are annual averages measured in thousands of unemployed"  ///
"and vacancy equivalents. These account for composition, for observed recruiting intensity (using" ///
" the Davis index) and observed search using the MPS index. They also include unobserved search" ///
"effort imputed using the method outlined in this paper.")
graph export "$path2\Figure3.png", replace

restore
}

sort year month
save `temp_data1', replace
*** Import matches and elasticity for figures 4-7
{
clear
import delimited figmain_2
tokenize mimplied m simplied elasticity_v A year month

forvalues i=1(1)7 {
	rename v`i' ``i''
}

sort year month
merge 1:1 year month using `temp_data1', assert(3) nogenerate
label var m "Actual Hires from JOLTS"
label var mimplied "Fitted Hires"
label var elasticity_v "Elasticity w.r.t vacancy"
}


*** Figure 4 Model Fit: Fitted and Actual Hires
{
	reg mimplied m
	predict m_resid, resid
	label var m_resid "Unexplained Hires"
	twoway scatter mimplied m, title("Fitted vs Actual") ytitle("Fitted Hires, in thousands") ///
	xtitle("Actual Hires, in thousands") graphr(color(white)) nodraw name(m1, replace)
	twoway scatter m_resid m, title("Unexplained Hires") ytitle("Unexplained Hires, in thousands") ///
	xtitle("Actual Hires, in thousands") graphr(color(white)) nodraw name(m2, replace)
	gr combine m1 m2,  title("Model Fit - Actual vs. Predicted Hires") graphr(color(white))
	graph export "$path2\Figure4_section6.png", replace
}


*** Figure 5: Efficiency vs. Recruiting effort conditional on Search
{
* Total observed search
reg A S 
predict Aresid, resid

reg v S
predict Rresid, resid

twoway scatter Aresid Rresid, title("Aggregate Matching Efficiency vs. Recruiting Effort") t2title("Conditional on Observed Search") ///
xtitle("Recruiting Effort (residual)") ytitle("Matching Efficiency (residual)") ///
note("Displayed are observed recruiting effort and implied matching efficiency" ///
"residualized using observed search") graphr(color(white))
graph export "$path2\Figure5_section6.png", replace
}


*** Figure 6 Elasticity of the matching function -- using the lasso fit before
{
tsline elasticity_v, tlabel(492 "1/2001" 540 "1/2005" 588 "1/2009" 636 "1/2013" 684 "1/2017") graphr(color(white)) ///
xtitle("") title("Elasticity w.r.t Vacancies") name(th1, replace) nodraw

gen tightness = v / S
gen month_in_yr = month(dofm(month))
// qui sum tightness if month_in_yr == 9 & year == 2007
// replace tightness = tightness / r(mean)

scatter elasticity_v tightness, mlabel("year") msymbol(i) graphr(color(white)) ///
title("V-Elasticity vs. Tightness") t2title("Tightness normalized to 1 in Sept. 2007") ///
name(th2, replace) nodraw
graph combine th1 th2, graphr(color(white))
graph export "$path2\Figure6_section6.png", replace
}


*** Figure 7: Matching Efficiency 
{
tssmooth ma Asmooth=A, window(9 1 9)
twoway (scatter A date) (tsline Asmooth, lwidth(thick)), tlabel(2001m1(48)2018m1) xtitle("") ///
title(Matching Efficiency) legend(off) graphr(color(white)) ///
note("The scatter are the monthly estimates and the smooth line a 18 months moving average" "of matching efficiency")
gr export "$path2\Figure7_section6.png", replace
}
pause

*** Import Data for Figure 8, Appendix Figures
{
clear
import delimited figmain_3
tokenize msmooth mAtsmooth mSsmooth mvtsmooth mSvtsmooth s_u_new s_u_original s_e s_n A tightness year month

forvalues i=1(1)13 {
	rename v`i' ``i''
}

label var msmooth "Actual Matches"
label var mAtsmooth "w/ efficiency A varying"
label var mSsmooth "w/ Search S varying" 
label var mvtsmooth "w/ vacancies V and recruiting effort R varying"
label var mSvtsmooth "w/ all observed variables (S,V,R) varying"
label var s_u_new "Updated MPS measure"
label var s_u_original "Original MPS measure"
label var A "Matching Efficiency"
label var tightness "Market Tightness"

recode month (0 = 1) (0.083333 = 2) (0.16667=3) (0.25=4) (0.33333=5) (0.41667 = 6) (0.5=7) (0.58333=8) (0.66667=9) (0.75=10) (0.83333=11) (0.91667=12)
sort year month
merge 1:1 year month using `temp_data1', assert(3) nogenerate
}

*** Figure 8
{
tsline msmooth mAtsmooth mSvtsmooth, title("Decomposing the Variation in Matches" "Observed and Unobserved Components") ///
lpattern(solid dash longdash) legend(nobox) graphr(color(white))
gr export "$path2\Figure8_section6.png", replace
}


/// Appendix Figures
{
// Appendix Figure 1-4

mvdecode s_u_original, mv(0=.)
tsline s_u_new s_u_original, lpattern(solid dash) graphregion(color(white)) title(Original and Updated MPS Measure)
gr export "$path2\figure1_appendix.png", replace

tsline s_e, graphr(color(white)) ytitle("") tlabel(2001m1(48)2018m1) title("Employed Search")
gr export "$path2\figure2_appendix.png", replace

tsline s_n, graphr(color(white)) ytitle("") tlabel(2001m1(48)2018m1) title("OLF Search")
gr export "$path2\figure3_appendix.png", replace

scatter A tightness, graphr(color(white)) title("Matching Efficiency and Market Tightness")
gr export "$path2\figure4_appendix.png", replace
}
